"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios = require('axios');
class BlockChain {
    constructor(_endpoint) {
        this.endpoint = _endpoint;
    }
    /**
     * get code from address
     * @param contract_address contract address
     */
    getCode(contract_address) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield axios.get(this.endpoint + `/accounts/${contract_address}/code`).catch(err => {
                throw err;
            });
            return result.data;
        });
    }
    /**
     * call deploy contract
     * @param byteCode byteCode for deploy contract
     */
    deployContractOfCall(byteCode) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield axios.post(this.endpoint + `/accounts`, {
                value: '0',
                data: '0x' + byteCode
            }).catch(err => {
                throw 'Deploy contract call error. ' + err.toString();
            });
            return result.data;
        });
    }
    /**
     * get accounts
     * @param address
     */
    accounts(address) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield axios.get(this.endpoint + `/accounts/${address}`).catch(err => {
                throw err.toString();
            });
            return result.data;
        });
    }
    /**
     * get transaction
     * @param _txId transaction hash
     */
    getTransaction(txId) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield axios.get(this.endpoint + `/transactions/${txId}`).catch(err => {
                throw err.response.data;
            });
            return result.data;
        });
    }
}
exports.BlockChain = BlockChain;
//# sourceMappingURL=blockchain.js.map