"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("./utils/util");
let solc = require('solc');
const linker = require('solc/linker');
/**
 * compile contract code with normal
 * @param sourceCode contract source code
 * @param isOptimizer optimizer
 */
function solcCompile(sourceCode, contract_name, _version, runs = 200, _path, _isOptimizer = false) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            if (_version) {
                const vPath = util_1.solcBinPath(_version, _path);
                solc = solc.setupMethods(require(vPath));
            }
            else {
                solc = require('solc');
            }
            // console.log('compile version: ', solc.semver())
            const bytecode = solcCompileStandardWrapper(solc, sourceCode, contract_name, runs, _isOptimizer);
            if (Object.keys(linker.findLinkReferences(bytecode)).length > 0)
                throw Error('link library not support');
            return bytecode;
        }
        catch (error) {
            throw error;
        }
    });
}
exports.solcCompile = solcCompile;
/**
 *
 * @param sourceCode contract source code
 * @param _isOptimizer default false
 */
function solcCompileStandardWrapper(_solc, sourceCode, contract_name, runs = 200, _isOptimizer = false) {
    const input = { content: { content: sourceCode } };
    const json = {
        language: 'Solidity',
        settings: {
            optimizer: {
                enabled: _isOptimizer,
                runs: runs
            },
            outputSelection: {
                '*': {
                    '*': ['evm.bytecode']
                }
            }
        },
        sources: input
    };
    try {
        const ret = _solc.compileStandardWrapper(JSON.stringify(json));
        const jsonRet = JSON.parse(ret);
        if (!jsonRet.contracts)
            throw Error(jsonRet["errors"][0]["formattedMessage"]);
        if ((Object.keys(jsonRet.contracts)).length === 0)
            throw Error(jsonRet["errors"][0]["formattedMessage"]);
        const contractNames = Object.keys(jsonRet.contracts.content);
        if (contractNames.length === 0)
            throw Error('compile contract source code failed');
        if (!jsonRet.contracts.content[contract_name])
            throw Error('mismatch target contract name');
        const bytecode = jsonRet.contracts.content[contract_name].evm.bytecode.object;
        if (!bytecode)
            throw Error('mismatch target contract name');
        return bytecode;
    }
    catch (error) {
        if (typeof error === 'string') {
            if (error.includes('abort(5)')) {
                throw Error('abort(5) at Error');
            }
            else {
                throw Error('compile failed. unknown error');
            }
        }
        throw error;
    }
}
exports.solcCompileStandardWrapper = solcCompileStandardWrapper;
//# sourceMappingURL=compile.js.map