"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios = require('axios');
const fs = require('fs');
const path = require('path');
function getVersionList() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log('Retrieving available version list...');
        const url = 'https://ethereum.github.io/solc-bin/bin/list.json';
        const res = yield axios.get(url).catch(err => {
            throw Error(`Error downloading file: ${err.toString()}`);
        });
        return res.data;
    });
}
function downloadingBin(version, binsPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const vList = yield getVersionList();
        const versionName = vList.releases[version];
        if (!versionName) {
            throw Error(`version [${version}] invalid`);
        }
        if (!fs.existsSync(binsPath)) {
            throw Error(`BinsPath not exists. ${binsPath}`);
        }
        console.log('Downloading version ', versionName);
        const binPath = path.join(binsPath, `/${versionName}`);
        const url = 'https://ethereum.github.io/solc-bin/bin/' + versionName;
        if (fs.existsSync(binPath)) {
            console.log(`version ${versionName} existed`);
            return binPath;
        }
        process.on('SIGINT', function () {
            console.log('Interrupted, removing file.');
            fs.unlinkSync(binPath);
            process.exit(1);
        });
        const writer = fs.createWriteStream(binPath);
        const response = yield axios({
            url,
            method: 'GET',
            responseType: 'stream'
        });
        response.data.pipe(writer);
        writer.on('finish', () => {
            console.log('Downloading Success!!!');
            process.exit(1);
        });
        writer.on('error', () => {
            console.log('Error downloading version');
            process.exit(1);
        });
    });
}
exports.downloadingBin = downloadingBin;
//# sourceMappingURL=downloadVersion.js.map