"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require('fs');
const path = require('path');
/**
 * verify
 * @param address address
 */
function verifyAddress(address) {
    return /^(0x)?[0-9a-fA-F]{40}$/.test(address);
}
exports.verifyAddress = verifyAddress;
function verifyTxId(txId) {
    return /^(0x)?[0-9a-fA-F]{64}$/.test(txId);
}
exports.verifyTxId = verifyTxId;
/**
 * return solc compiler path
 * @param version version of compiler
 * @param binsPath bins directory
 */
function solcBinPath(version, binsPath) {
    const versions = getSolcbinsFileNames(binsPath);
    for (const v of versions) {
        if (v.startsWith('soljson-v' + version)) {
            return path.join(binsPath, v + '.js');
        }
    }
    return '';
}
exports.solcBinPath = solcBinPath;
/**
 * get filenames
 */
function findFileNamesSync(startPath) {
    let result = [];
    function finder(startPath) {
        let files = fs.readdirSync(startPath);
        files.forEach((val, _index) => {
            let fPath = path.join(startPath, val);
            let stats = fs.statSync(fPath);
            if (stats.isDirectory())
                finder(fPath);
            if (stats.isFile())
                result.push(val);
        });
    }
    finder(startPath);
    return result;
}
exports.findFileNamesSync = findFileNamesSync;
/**
 * get file name of solc compiler
 * @param path solc bins directory
 */
function getSolcbinsFileNames(path) {
    const compilers = findFileNamesSync(path);
    const cleanSuffix = compilers.map(solcV => solcV.split('.js')[0]);
    return cleanSuffix.sort();
}
exports.getSolcbinsFileNames = getSolcbinsFileNames;
/**
 * decode URI base64
 **/
function decodeBase64(str) {
    return decodeURIComponent(Buffer.from(str, 'base64').toString('utf-8'));
}
exports.decodeBase64 = decodeBase64;
/**
 * encode URI base64
 */
function encodeBase64(str) {
    return Buffer.from(encodeURIComponent(str)).toString('base64');
}
exports.encodeBase64 = encodeBase64;
//# sourceMappingURL=util.js.map